@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use Carp;
 
-our $VERSION = 'v0.3.8'; # VERSION
+our $VERSION = 'v0.4.0'; # VERSION
 
 use Moose;
 with qw(
@@ -14,6 +14,7 @@ with qw(
 	Business::CyberSource::Request::Role::PurchaseInfo
 	Business::CyberSource::Request::Role::CreditCardInfo
 	Business::CyberSource::Request::Role::BusinessRules
+	Business::CyberSource::Request::Role::DCC
 );
 
 use Business::CyberSource::Response;
@@ -22,23 +23,9 @@ use MooseX::StrictConstructor;
 sub submit {
 	my $self = shift;
 
-	my $payload = {
-		billTo                => $self->_billing_info,
-		card                  => $self->_cc_info,
-		ccAuthService => {
-			run => 'true',
-		},
-	};
+	$self->_request_data->{ccAuthService}{run} = 'true';
 
-	if ( keys $self->_business_rules ) {
-		$payload->{businessRules} = $self->_business_rules;
-	}
-
-	if ( $self->has_items and not $self->items_is_empty ) {
-		$payload->{item} = [ @{ $self->_item_info } ];
-	}
-
-	my $r = $self->_build_request( $payload );
+	my $r = $self->_build_request;
 
 	my $res;
 	if ( $r->{decision} eq 'ACCEPT' or $r->{decision} eq 'REJECT' ) {
@@ -123,7 +110,7 @@ Business::CyberSource::Request::Authorization - CyberSource Authorization Reques
 
 =head1 VERSION
 
-version v0.3.8
+version v0.4.0
 
 =head1 SYNOPSIS
 
@@ -195,22 +182,18 @@ cards.
 
 =head1 ATTRIBUTES
 
+=head2 foreign_amount
+
+Reader: foreign_amount
+
+Type: MooseX::Types::Common::Numeric::PositiveOrZeroNum
+
 =head2 ignore_cv_result
 
 Reader: ignore_cv_result
 
 Type: Bool
 
-=head2 street
-
-Reader: street
-
-Type: MooseX::Types::Varchar::Varchar[60]
-
-This attribute is required.
-
-Additional documentation: First line of the billing street address as it appears on the credit card issuer's records. alias: C<street1>
-
 =head2 client_env
 
 Reader: client_env
@@ -263,6 +246,14 @@ This attribute is required.
 
 Additional documentation: your SOAP transaction key
 
+=head2 postal_code
+
+Reader: postal_code
+
+Type: MooseX::Types::Varchar::Varchar[10]
+
+Additional documentation: Postal code for the billing address. The postal code must consist of 5 to 9 digits. Required if C<country> is "US" or "CA"alias: C<postal_code>
+
 =head2 cybs_api_version
 
 Reader: cybs_api_version
@@ -313,14 +304,6 @@ This attribute is required.
 
 Additional documentation: Your CyberSource merchant ID. Use the same merchantID for evaluation, testing, and production
 
-=head2 card_type
-
-Reader: card_type
-
-Type: MooseX::Types::CyberSource::CardTypeCode
-
-Additional documentation: Type of card to authorize
-
 =head2 credit_card
 
 Reader: credit_card
@@ -331,13 +314,13 @@ This attribute is required.
 
 Additional documentation: Customer's credit card number
 
-=head2 zip
+=head2 card_type
 
-Reader: zip
+Reader: card_type
 
-Type: MooseX::Types::Varchar::Varchar[10]
+Type: MooseX::Types::CyberSource::CardTypeCode
 
-Additional documentation: Postal code for the billing address. The postal code must consist of 5 to 9 digits. Required if C<country> is "US" or "CA"alias: C<postal_code>
+Additional documentation: Type of card to authorize
 
 =head2 street2
 
@@ -373,22 +356,6 @@ Reader: ignore_avs_result
 
 Type: Bool
 
-=head2 ip
-
-Reader: ip
-
-Type: MooseX::Types::NetAddr::IP::NetAddrIPv4
-
-Additional documentation: Customer's IP address. alias: C<ip_address>
-
-=head2 cv_indicator
-
-Reader: cv_indicator
-
-Type: MooseX::Types::CyberSource::CvIndicator
-
-Additional documentation: Flag that indicates whether a CVN code was sent
-
 =head2 last_name
 
 Reader: last_name
@@ -399,6 +366,14 @@ This attribute is required.
 
 Additional documentation: Customer's last name. The value should be the same as the one that is on the card.
 
+=head2 cv_indicator
+
+Reader: cv_indicator
+
+Type: MooseX::Types::CyberSource::CvIndicator
+
+Additional documentation: Flag that indicates whether a CVN code was sent
+
 =head2 currency
 
 Reader: currency
@@ -435,6 +410,14 @@ Type: MooseX::Types::Varchar::Varchar[60]
 
 Additional documentation: Fourth line of the billing street address.
 
+=head2 ip_address
+
+Reader: ip_address
+
+Type: MooseX::Types::NetAddr::IP::NetAddrIPv4
+
+Additional documentation: Customer's IP address. alias: C<ip_address>
+
 =head2 country
 
 Reader: country
@@ -445,12 +428,40 @@ This attribute is required.
 
 Additional documentation: ISO 2 character country code (as it would apply to a credit card billing statement)
 
+=head2 exchange_rate
+
+Reader: exchange_rate
+
+Type: MooseX::Types::Common::Numeric::PositiveOrZeroNum
+
+=head2 exchange_rate_timestamp
+
+Reader: exchange_rate_timestamp
+
+Type: Str
+
 =head2 ignore_validate_result
 
 Reader: ignore_validate_result
 
 Type: Bool
 
+=head2 full_name
+
+Reader: full_name
+
+Type: MooseX::Types::Varchar::Varchar[60]
+
+=head2 street1
+
+Reader: street1
+
+Type: MooseX::Types::Varchar::Varchar[60]
+
+This attribute is required.
+
+Additional documentation: First line of the billing street address as it appears on the credit card issuer's records. alias: C<street1>
+
 =head2 cc_exp_year
 
 Reader: cc_exp_year
@@ -469,6 +480,20 @@ Type: MooseX::Types::Path::Class::File
 
 Additional documentation: provided by the library
 
+=head2 dcc_indicator
+
+Reader: dcc_indicator
+
+Type: MooseX::Types::CyberSource::DCCIndicator
+
+=head2 foreign_currency
+
+Reader: foreign_currency
+
+Type: MooseX::Types::Locale::Currency::CurrencyCode
+
+Additional documentation: Billing currency returned by the DCC service. For the possible values, see the ISO currency codes
+
 =head2 ignore_dav_result
 
 Reader: ignore_dav_result
