@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use Carp;
 
-our $VERSION = 'v0.3.8'; # VERSION
+our $VERSION = 'v0.4.0'; # VERSION
 
 use Moose::Role;
 use MooseX::Aliases;
@@ -18,6 +18,10 @@ has first_name => (
 	required => 1,
 	is       => 'ro',
 	isa      => Varchar[60],
+	trigger  => sub {
+		my $self = shift;
+		$self->_request_data->{billTo}{firstName} = $self->first_name;
+	},
 	documentation => 'Customer\'s first name.The value should be the same as '
 		. 'the one that is on the card.',
 );
@@ -26,15 +30,24 @@ has last_name => (
 	required => 1,
 	is       => 'ro',
 	isa      => Varchar[60],
+	trigger  => sub {
+		my $self = shift;
+		$self->_request_data->{billTo}{lastName} = $self->last_name;
+	},
 	documentation => 'Customer\'s last name. The value should be the same as '
 		. 'the one that is on the card.'
 );
 
-has street => (
+has street1 => (
 	required => 1,
 	is       => 'ro',
 	isa      => Varchar[60],
-	alias    => 'street1',
+	alias    => 'street',
+	trigger  => sub {
+		my $self = shift;
+		$self->_request_data->{billTo}{street1} = $self->street1;
+		street1    => $self->street1,
+	},
 	documentation => 'First line of the billing street address as it '
 		. 'appears on the credit card issuer\'s records. alias: C<street1>',
 );
@@ -44,6 +57,10 @@ has street2 => (
 	is       => 'ro',
 	isa      => Varchar[60],
 	predicate => 'has_street2',
+	trigger  => sub {
+		my $self = shift;
+		$self->_request_data->{billTo}{street2} = $self->street2;
+	},
 	documentation => 'Second line of the billing street address.',
 );
 
@@ -52,6 +69,10 @@ has street3 => (
 	is       => 'ro',
 	isa      => Varchar[60],
 	predicate => 'has_street3',
+	trigger  => sub {
+		my $self = shift;
+		$self->_request_data->{billTo}{street3} = $self->street3;
+	},
 	documentation => 'Third line of the billing street address.',
 );
 
@@ -60,6 +81,10 @@ has street4 => (
 	is       => 'ro',
 	isa      => Varchar[60],
 	predicate => 'has_street4',
+	trigger  => sub {
+		my $self = shift;
+		$self->_request_data->{billTo}{street4} = $self->street4;
+	},
 	documentation => 'Fourth line of the billing street address.',
 );
 
@@ -67,6 +92,10 @@ has city => (
 	required => 1,
 	is       => 'ro',
 	isa      => Varchar[50],
+	trigger  => sub {
+		my $self = shift;
+		$self->_request_data->{billTo}{city} = $self->city;
+	},
 	documentation => 'City of the billing address.',
 );
 
@@ -76,6 +105,10 @@ has state => (
 	is       => 'ro',
 	isa      => Varchar[2],
 	predicate => 'has_state',
+	trigger  => sub {
+		my $self = shift;
+		$self->_request_data->{billTo}{state} = $self->state;
+	},
 	documentation => 'State or province of the billing address. '
 		. 'Use the two-character codes. alias: C<province>',
 );
@@ -85,16 +118,24 @@ has country => (
 	coerce   => 1,
 	is       => 'ro',
 	isa      => CountryCode,
+	trigger  => sub {
+		my $self = shift;
+		$self->_request_data->{billTo}{country} = $self->country;
+	},
 	documentation => 'ISO 2 character country code '
 		. '(as it would apply to a credit card billing statement)',
 );
 
-has zip => (
+has postal_code => (
 	required => 0,
-	alias    => 'postal_code',
+	alias    => 'zip',
 	is       => 'ro',
 	isa      => Varchar[10],
 	predicate => 'has_zip',
+	trigger  => sub {
+		my $self = shift;
+		$self->_request_data->{billTo}{postalCode} = $self->postal_code;
+	},
 	documentation => 'Postal code for the billing address. '
 		. 'The postal code must consist of 5 to 9 digits. '
 		. 'Required if C<country> is "US" or "CA"'
@@ -105,42 +146,28 @@ has email => (
 	required => 1,
 	is       => 'ro',
 	isa      => EmailAddress,
+	trigger  => sub {
+		my $self = shift;
+		$self->_request_data->{billTo}{email} = $self->email;
+	},
 	documentation => 'Customer\'s email address, including the full domain '
 		. 'name',
 );
 
-has ip => (
+has ip_address => (
 	required => 0,
-	alias    => 'ip_address',
+	alias    => 'ip',
 	coerce   => 1,
 	is       => 'ro',
 	isa      => NetAddrIPv4,
 	predicate => 'has_ip',
+	trigger  => sub {
+		my $self = shift;
+		$self->_request_data->{billTo}{ipAddress} = $self->ip_address;
+	},
 	documentation => 'Customer\'s IP address. alias: C<ip_address>',
 );
 
-sub _billing_info {
-	my $self = shift;
-
-	my $i = {
-		firstName  => $self->first_name,
-		lastName   => $self->last_name,
-		street1    => $self->street1,
-		city       => $self->city,
-		country    => $self->country,
-		email      => $self->email,
-	};
-
-	$i->{ipAddress}  = $self->ip->addr if $self->has_ip;
-	$i->{state}      = $self->state    if $self->has_state;
-	$i->{postalCode} = $self->zip      if $self->has_zip;
-	$i->{street2}    = $self->street2  if $self->has_street2;
-	$i->{street3}    = $self->street3  if $self->has_street3;
-	$i->{street4}    = $self->street3  if $self->has_street4;
-
-	return $i;
-}
-
 1;
 
 # ABSTRACT: Role for requests that require "bill to" information
@@ -154,7 +181,7 @@ Business::CyberSource::Request::Role::BillingInfo - Role for requests that requi
 
 =head1 VERSION
 
-version v0.3.8
+version v0.4.0
 
 =head1 BUGS
 
