@@ -5,10 +5,10 @@ use warnings;
 use Carp;
 use namespace::autoclean;
 
-our $VERSION = 'v0.3.8'; # VERSION
+our $VERSION = 'v0.4.0'; # VERSION
 
 use Moose::Role;
-use MooseX::Types::Moose   qw( HashRef );
+use MooseX::Types::Moose   qw( HashRef Str );
 use MooseX::Types::Varchar qw( Varchar );
 use MooseX::Types::URI     qw( Uri     );
 
@@ -27,7 +27,7 @@ use XML::Compile::SOAP11;
 use XML::Compile::Transport::SOAPHTTP;
 
 sub _build_request {
-	my ( $self, $payload ) = @_;
+	my $self = shift;
 
 	my $wss = XML::Compile::SOAP::WSS->new( version => '1.1' );
 
@@ -41,12 +41,10 @@ sub _build_request {
 	my ( $answer, $trace ) = $call->(
 		wsse_Security         => $security,
 		merchantID            => $self->username,
-		merchantReferenceCode => $self->reference_code,
 		clientEnvironment     => $self->client_env,
 		clientLibrary         => $self->client_name,
 		clientLibraryVersion  => $self->client_version,
-		purchaseTotals        => $self->_purchase_info,
-		%{ $payload },
+		%{ $self->_request_data },
 	);
 
 	$self->trace( $trace );
@@ -102,6 +100,10 @@ has reference_code => (
 	required => 1,
 	is       => 'ro',
 	isa      => Varchar[50],
+	trigger  => sub {
+		my $self = shift;
+		$self->_request_data->{merchantReferenceCode} = $self->reference_code;
+	},
 );
 
 has trace => (
@@ -109,6 +111,14 @@ has trace => (
 	isa    => 'XML::Compile::SOAP::Trace',
 );
 
+has _request_data => (
+	required => 1,
+	init_arg => undef,
+	is       => 'rw',
+	isa      => HashRef,
+	default => sub { { } },
+);
+
 1;
 
 # ABSTRACT: Request Role
@@ -123,7 +133,7 @@ Business::CyberSource::Request::Role::Common - Request Role
 
 =head1 VERSION
 
-version v0.3.8
+version v0.4.0
 
 =for Pod::Coverage BUILD
 
