@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = 'v0.3.8'; # VERSION
+our $VERSION = 'v0.4.0'; # VERSION
 
 use Moose::Role;
 
@@ -18,28 +18,52 @@ has items => (
 	traits    => ['Array'],
 	handles   => {
 		items_is_empty => 'is_empty',
-	}
-);
+	},
+	trigger   => sub {
+		my $self = shift;
+		my $items = [ ];
+		if ( $self->has_items and not $self->items_is_empty ) {
+			my $i = 0;
+			foreach my $item ( @{ $self->items } ) {
+				my $h = {
+					id        => $i,
+					quantity  => $item->{quantity},
+					unitPrice => $item->{unit_price},
+				};
+				$h->{productCode}
+					= $item->{product_code} if $item->{product_code}
+					;
 
-sub _item_info {
-	my $self = shift;
+				$h->{productName}
+					= $item->{product_name} if $item->{product_name}
+					;
 
-	my $items = [ ];
-	if ( $self->has_items and not $self->items_is_empty ) {
-		my $i = 0;
-		foreach my $item ( @{ $self->items } ) {
-			my $h = {
-				id        => $i,
-				quantity  => $item->{quantity},
-				unitPrice => $item->{unit_price},
-			};
-			push @{ $items }, $h;
-			$i++;
+				$h->{productSKU}
+					= $item->{product_sku} if $item->{product_sku}
+					;
+
+				$h->{productRisk}
+					= $item->{product_risk} if $item->{product_risk}
+					;
+
+				$h->{taxAmount}
+					= $item->{tax_amount} if $item->{tax_amount}
+					;
+
+				$h->{taxRate}
+					= $item->{tax_rate} if $item->{tax_rate}
+					;
+				$h->{nationalTax}
+					= $item->{national_tax} if $item->{national_tax}
+					;
+
+				push @{ $items }, $h;
+				$i++;
+			}
 		}
-	}
-
-	return $items;
-}
+		$self->_request_data->{item} = $items;
+	},
+);
 
 1;
 
@@ -54,7 +78,7 @@ Business::CyberSource::Request::Role::Items - Role that provides Items
 
 =head1 VERSION
 
-version v0.3.8
+version v0.4.0
 
 =head1 BUGS
 
