@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = 'v0.3.8'; # VERSION
+our $VERSION = 'v0.4.0'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request::Credit';
@@ -28,7 +28,7 @@ Business::CyberSource::Request::StandAloneCredit - CyberSource Credit Request Ob
 
 =head1 VERSION
 
-version v0.3.8
+version v0.4.0
 
 =head1 SYNOPSIS
 
@@ -62,15 +62,11 @@ This object allows you to create a request for a standalone credit.
 
 =head1 ATTRIBUTES
 
-=head2 street
+=head2 foreign_amount
 
-Reader: street
+Reader: foreign_amount
 
-Type: MooseX::Types::Varchar::Varchar[60]
-
-This attribute is required.
-
-Additional documentation: First line of the billing street address as it appears on the credit card issuer's records. alias: C<street1>
+Type: MooseX::Types::Common::Numeric::PositiveOrZeroNum
 
 =head2 client_env
 
@@ -124,6 +120,14 @@ This attribute is required.
 
 Additional documentation: your SOAP transaction key
 
+=head2 postal_code
+
+Reader: postal_code
+
+Type: MooseX::Types::Varchar::Varchar[10]
+
+Additional documentation: Postal code for the billing address. The postal code must consist of 5 to 9 digits. Required if C<country> is "US" or "CA"alias: C<postal_code>
+
 =head2 cybs_api_version
 
 Reader: cybs_api_version
@@ -168,14 +172,6 @@ This attribute is required.
 
 Additional documentation: Your CyberSource merchant ID. Use the same merchantID for evaluation, testing, and production
 
-=head2 card_type
-
-Reader: card_type
-
-Type: MooseX::Types::CyberSource::CardTypeCode
-
-Additional documentation: Type of card to authorize
-
 =head2 credit_card
 
 Reader: credit_card
@@ -186,13 +182,13 @@ This attribute is required.
 
 Additional documentation: Customer's credit card number
 
-=head2 zip
+=head2 card_type
 
-Reader: zip
+Reader: card_type
 
-Type: MooseX::Types::Varchar::Varchar[10]
+Type: MooseX::Types::CyberSource::CardTypeCode
 
-Additional documentation: Postal code for the billing address. The postal code must consist of 5 to 9 digits. Required if C<country> is "US" or "CA"alias: C<postal_code>
+Additional documentation: Type of card to authorize
 
 =head2 street2
 
@@ -218,14 +214,6 @@ Type: MooseX::Types::Varchar::Varchar[60]
 
 Additional documentation: Third line of the billing street address.
 
-=head2 ip
-
-Reader: ip
-
-Type: MooseX::Types::NetAddr::IP::NetAddrIPv4
-
-Additional documentation: Customer's IP address. alias: C<ip_address>
-
 =head2 cv_indicator
 
 Reader: cv_indicator
@@ -280,6 +268,14 @@ Type: MooseX::Types::Varchar::Varchar[60]
 
 Additional documentation: Fourth line of the billing street address.
 
+=head2 ip_address
+
+Reader: ip_address
+
+Type: MooseX::Types::NetAddr::IP::NetAddrIPv4
+
+Additional documentation: Customer's IP address. alias: C<ip_address>
+
 =head2 country
 
 Reader: country
@@ -290,6 +286,34 @@ This attribute is required.
 
 Additional documentation: ISO 2 character country code (as it would apply to a credit card billing statement)
 
+=head2 exchange_rate
+
+Reader: exchange_rate
+
+Type: MooseX::Types::Common::Numeric::PositiveOrZeroNum
+
+=head2 exchange_rate_timestamp
+
+Reader: exchange_rate_timestamp
+
+Type: Str
+
+=head2 full_name
+
+Reader: full_name
+
+Type: MooseX::Types::Varchar::Varchar[60]
+
+=head2 street1
+
+Reader: street1
+
+Type: MooseX::Types::Varchar::Varchar[60]
+
+This attribute is required.
+
+Additional documentation: First line of the billing street address as it appears on the credit card issuer's records. alias: C<street1>
+
 =head2 cc_exp_year
 
 Reader: cc_exp_year
@@ -308,6 +332,20 @@ Type: MooseX::Types::Path::Class::File
 
 Additional documentation: provided by the library
 
+=head2 dcc_indicator
+
+Reader: dcc_indicator
+
+Type: MooseX::Types::CyberSource::DCCIndicator
+
+=head2 foreign_currency
+
+Reader: foreign_currency
+
+Type: MooseX::Types::Locale::Currency::CurrencyCode
+
+Additional documentation: Billing currency returned by the DCC service. For the possible values, see the ISO currency codes
+
 =head2 client_name
 
 Reader: client_name
