@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = 'v0.3.8'; # VERSION
+our $VERSION = 'v0.4.0'; # VERSION
 
 use Moose::Role;
 use MooseX::Types::Locale::Currency qw( CurrencyCode );
@@ -13,6 +13,12 @@ has currency => (
 	required => 1,
 	is       => 'ro',
 	isa      => CurrencyCode,
+	trigger => sub {
+		my $self = shift;
+		if ( $self->meta->find_attribute_by_name( '_request_data' ) ) {
+			$self->_request_data->{purchaseTotals}{currency} = $self->currency;
+		}
+	},
 );
 
 1;
@@ -28,7 +34,7 @@ Business::CyberSource::Role::Currency - Role to apply to requests and responses
 
 =head1 VERSION
 
-version v0.3.8
+version v0.4.0
 
 =head1 BUGS
 
